summaryrefslogtreecommitdiffstats
path: root/kmail/kmailicalifaceimpl.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commit4c6f8d69e2d1501837affb472c4eb8fec4462240 (patch)
tree766a8ad7939fcf3eec534184c36bd0e0f80489e2 /kmail/kmailicalifaceimpl.cpp
parent469cc56a805bd3d6940d54adbef554877c29853c (diff)
downloadtdepim-4c6f8d69e2d1501837affb472c4eb8fec4462240.tar.gz
tdepim-4c6f8d69e2d1501837affb472c4eb8fec4462240.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmailicalifaceimpl.cpp')
-rw-r--r--kmail/kmailicalifaceimpl.cpp60
1 files changed, 30 insertions, 30 deletions
diff --git a/kmail/kmailicalifaceimpl.cpp b/kmail/kmailicalifaceimpl.cpp
index bf0e5b8c..82084b13 100644
--- a/kmail/kmailicalifaceimpl.cpp
+++ b/kmail/kmailicalifaceimpl.cpp
@@ -260,7 +260,7 @@ bool KMailICalIfaceImpl::updateAttachment( KMMessage& msg,
KMMessagePart msgPart;
msgPart.setName( attachmentName );
- const int iSlash = attachmentMimetype.tqfind('/');
+ const int iSlash = attachmentMimetype.find('/');
const TQCString sType = attachmentMimetype.left( iSlash ).latin1();
const TQCString sSubtype = attachmentMimetype.mid( iSlash+1 ).latin1();
msgPart.setTypeStr( sType );
@@ -309,7 +309,7 @@ bool KMailICalIfaceImpl::updateAttachment( KMMessage& msg,
// Look for the attachment with the right mimetype
bool KMailICalIfaceImpl::kolabXMLFoundAndDecoded( const KMMessage& msg, const TQString& mimetype, TQString& s )
{
- const int iSlash = mimetype.tqfind('/');
+ const int iSlash = mimetype.find('/');
const TQCString sType = mimetype.left( iSlash ).latin1();
const TQCString sSubtype = mimetype.mid( iSlash+1 ).latin1();
DwBodyPart* part = findBodyPartByMimeType( msg, sType, sSubtype, true /* starts with sSubtype, to accept application/x-vnd.kolab.contact.distlist */ );
@@ -325,7 +325,7 @@ bool KMailICalIfaceImpl::kolabXMLFoundAndDecoded( const KMMessage& msg, const TQ
// Delete an attachment in an existing mail.
// return value: wrong if attachment could not be deleted
//
// This code could be optimized: for now we just tqreplace
// the attachment by an empty dummy attachment since Mimelib
// does not provide an option for deleting attachments yet.
bool KMailICalIfaceImpl::deleteAttachment( KMMessage& msg,
@@ -566,7 +566,7 @@ TQMap<TQ_UINT32, TQString> KMailICalIfaceImpl::incidencesKolab( const TQString&
KMMessage* msg = f->storage()->readTemporaryMsg(i);
#endif
if ( msg ) {
- const int iSlash = mimetype.tqfind('/');
+ const int iSlash = mimetype.find('/');
const TQCString sType = mimetype.left( iSlash ).latin1();
const TQCString sSubtype = mimetype.mid( iSlash+1 ).latin1();
if ( sType.isEmpty() || sSubtype.isEmpty() ) {
@@ -616,7 +616,7 @@ void KMailICalIfaceImpl::slotMessageRetrieved( KMMessage* msg )
TQ_UINT32 sernum = msg->getMsgSerNum();
// do we have an accumulator for this folder?
- Accumulator *ac = mAccumulators.tqfind( tqparent->location() );
+ Accumulator *ac = mAccumulators.find( tqparent->location() );
if( ac ) {
TQString s;
if ( !vPartFoundAndDecoded( msg, s ) ) return;
@@ -637,7 +637,7 @@ void KMailICalIfaceImpl::slotMessageRetrieved( KMMessage* msg )
slotIncidenceAdded( msg->tqparent(), msg->getMsgSerNum() );
}
- if ( mTheUnGetMes.tqcontains( sernum ) ) {
+ if ( mTheUnGetMes.contains( sernum ) ) {
mTheUnGetMes.remove( sernum );
int i = 0;
KMFolder* folder = 0;
@@ -666,7 +666,7 @@ int KMailICalIfaceImpl::dimapAccounts()
static TQString subresourceLabelForPresentation( const KMFolder * folder )
{
- if( KMailICalIfaceImpl::getResourceMap()->tqcontains( folder->location() ) ) {
+ if( KMailICalIfaceImpl::getResourceMap()->contains( folder->location() ) ) {
return folder->label();
}
@@ -1044,7 +1044,7 @@ TQStringList KMailICalIfaceImpl::listAttachments(const TQString & resource, TQ_U
TQString name;
DwMediaType& contentType = part->Headers().ContentType();
if ( TQString( contentType.SubtypeStr().c_str() ).startsWith( "x-vnd.kolab." )
- || TQString( contentType.SubtypeStr().c_str() ).tqcontains( "tnef" ) )
+ || TQString( contentType.SubtypeStr().c_str() ).contains( "tnef" ) )
continue;
if ( !part->Headers().ContentDisposition().Filename().empty() )
name = part->Headers().ContentDisposition().Filename().c_str();
@@ -1131,7 +1131,7 @@ void KMailICalIfaceImpl::slotIncidenceAdded( KMFolder* folder,
mUIDToSerNum.insert( uid, sernum );
// tell the resource if we didn't trigger this ourselves
- if ( mInTransit.tqcontains( uid ) ) {
+ if ( mInTransit.contains( uid ) ) {
mInTransit.remove( uid );
}
incidenceAdded( type, folder->location(), sernum, format, s );
@@ -1213,7 +1213,7 @@ void KMailICalIfaceImpl::slotRefreshFolder( KMFolder* folder)
if( mUseResourceIMAP && folder ) {
if( folder == mCalendar || folder == mContacts
|| folder == mNotes || folder == mTasks
- || folder == mJournals || mExtraFolders.tqfind( folder->location() ) ) {
+ || folder == mJournals || mExtraFolders.find( folder->location() ) ) {
// Refresh the folder of this type
KMail::FolderContentsType ct = folder->storage()->contentsType();
slotRefresh( s_folderContentsType[ct].contentsTypeStr );
@@ -1257,7 +1257,7 @@ KMFolder* KMailICalIfaceImpl::folderFromType( const TQString& type,
bool KMailICalIfaceImpl::isResourceFolder( KMFolder* folder ) const
{
return mUseResourceIMAP && folder &&
- ( isStandardResourceFolder( folder ) || mExtraFolders.tqfind( folder->location() )!=0 );
+ ( isStandardResourceFolder( folder ) || mExtraFolders.find( folder->location() )!=0 );
}
bool KMailICalIfaceImpl::isStandardResourceFolder( KMFolder* folder ) const
@@ -1286,7 +1286,7 @@ KFolderTreeItem::Type KMailICalIfaceImpl::folderType( KMFolder* folder ) const
if( mUseResourceIMAP && folder ) {
if( folder == mCalendar || folder == mContacts
|| folder == mNotes || folder == mTasks
- || folder == mJournals || mExtraFolders.tqfind( folder->location() ) ) {
+ || folder == mJournals || mExtraFolders.find( folder->location() ) ) {
KMail::FolderContentsType ct = folder->storage()->contentsType();
return s_folderContentsType[ct].treeItemType;
}
@@ -1352,7 +1352,7 @@ TQString KMailICalIfaceImpl::folderName( KFolderTreeItem::Type type, int languag
// Find message matching a given UID
KMMessage *KMailICalIfaceImpl::findMessageByUID( const TQString& uid, KMFolder* folder )
{
- if( !folder || !mUIDToSerNum.tqcontains( uid ) ) return 0;
+ if( !folder || !mUIDToSerNum.contains( uid ) ) return 0;
int i;
KMFolder *aFolder;
KMMsgDict::instance()->getLocation( mUIDToSerNum[uid], &aFolder, &i );
@@ -1387,7 +1387,7 @@ void KMailICalIfaceImpl::deleteMsg( KMMessage *msg )
// Commands are now delayed; can't use that anymore, we need immediate deletion
//( new KMDeleteMsgCommand( msg->tqparent(), msg ) )->start();
KMFolder *srcFolder = msg->tqparent();
- int idx = srcFolder->tqfind(msg);
+ int idx = srcFolder->find(msg);
assert(idx != -1);
// kill existing jobs since we are about to delete the message
srcFolder->ignoreJobsForMessage( msg );
@@ -1415,7 +1415,7 @@ void KMailICalIfaceImpl::folderContentsTypeChanged( KMFolder* folder,
// Check if already know that 'extra folder'
const TQString location = folder->location();
- ExtraFolder* ef = mExtraFolders.tqfind( location );
+ ExtraFolder* ef = mExtraFolders.find( location );
if ( ef && ef->folder ) {
// Notify that the old folder resource is no longer available
subresourceDeleted(folderContentsType( folder->storage()->contentsType() ), location );
@@ -1469,7 +1469,7 @@ KMFolder* KMailICalIfaceImpl::extraFolder( const TQString& type,
if ( t < 1 || t > 5 )
return 0;
- ExtraFolder* ef = mExtraFolders.tqfind( folder );
+ ExtraFolder* ef = mExtraFolders.find( folder );
if ( ef && ef->folder && ef->folder->storage()->contentsType() == t )
return ef->folder;
@@ -1478,7 +1478,7 @@ KMFolder* KMailICalIfaceImpl::extraFolder( const TQString& type,
KMailICalIfaceImpl::StorageFormat KMailICalIfaceImpl::storageFormat( KMFolder* folder ) const
{
- FolderInfoMap::ConstIterator it = mFolderInfoMap.tqfind( folder );
+ FolderInfoMap::ConstIterator it = mFolderInfoMap.find( folder );
if ( it != mFolderInfoMap.end() )
return (*it).mStorageFormat;
return globalStorageFormat();
@@ -1486,7 +1486,7 @@ KMailICalIfaceImpl::StorageFormat KMailICalIfaceImpl::storageFormat( KMFolder* f
void KMailICalIfaceImpl::setStorageFormat( KMFolder* folder, StorageFormat format )
{
- FolderInfoMap::Iterator it = mFolderInfoMap.tqfind( folder );
+ FolderInfoMap::Iterator it = mFolderInfoMap.find( folder );
if ( it != mFolderInfoMap.end() ) {
(*it).mStorageFormat = format;
} else {
@@ -1500,7 +1500,7 @@ void KMailICalIfaceImpl::setStorageFormat( KMFolder* folder, StorageFormat forma
void KMailICalIfaceImpl::addFolderChange( KMFolder* folder, FolderChanges changes )
{
- FolderInfoMap::Iterator it = mFolderInfoMap.tqfind( folder );
+ FolderInfoMap::Iterator it = mFolderInfoMap.find( folder );
if ( it != mFolderInfoMap.end() ) {
(*it).mChanges = static_cast<FolderChanges>( (*it).mChanges | changes );
} else { // Otherwise, well, it's a folder we don't care about.
@@ -1529,7 +1529,7 @@ KMailICalIfaceImpl::FolderInfo KMailICalIfaceImpl::readFolderInfo( const KMFolde
void KMailICalIfaceImpl::folderSynced( KMFolder* folder, const KURL& folderURL )
{
- FolderInfoMap::Iterator it = mFolderInfoMap.tqfind( folder );
+ FolderInfoMap::Iterator it = mFolderInfoMap.find( folder );
if ( it != mFolderInfoMap.end() && (*it).mChanges ) {
handleFolderSynced( folder, folderURL, (*it).mChanges );
(*it).mChanges = NoChange;
@@ -1560,7 +1560,7 @@ void KMailICalIfaceImpl::triggerKolabFreeBusy( const KURL& folderURL )
{
/* Steffen said: you must issue an authenticated HTTP GET request to
https://kolabserver/freebusy/trigger/user@domain/Folder/NestedFolder.pfb
- (tqreplace .pfb with .xpfb for extended fb lists). */
+ (replace .pfb with .xpfb for extended fb lists). */
KURL httpURL( folderURL );
// Keep username ("user@domain"), pass, and host from the imap url
httpURL.setProtocol( "https" );
@@ -1569,7 +1569,7 @@ void KMailICalIfaceImpl::triggerKolabFreeBusy( const KURL& folderURL )
// IMAP path is either /INBOX/<path> or /user/someone/<path>
TQString path = folderURL.path( -1 );
Q_ASSERT( path.startsWith( "/" ) );
- int secondSlash = path.tqfind( '/', 1 );
+ int secondSlash = path.find( '/', 1 );
if ( secondSlash == -1 ) {
kdWarning() << "KCal::ResourceKolab::fromKMailFolderSynced path is too short: " << path << endl;
return;
@@ -1617,7 +1617,7 @@ void KMailICalIfaceImpl::slotFolderLocationChanged( const TQString &oldLocation,
const TQString &newLocation )
{
KMFolder *folder = findResourceFolder( oldLocation );
- ExtraFolder* ef = mExtraFolders.tqfind( oldLocation );
+ ExtraFolder* ef = mExtraFolders.find( oldLocation );
if ( ef ) {
// reuse the ExtraFolder entry, but adjust the key
mExtraFolders.setAutoDelete( false );
@@ -1645,7 +1645,7 @@ KMFolder* KMailICalIfaceImpl::findResourceFolder( const TQString& resource )
return mJournals;
// No luck. Try the extrafolders
- ExtraFolder* ef = mExtraFolders.tqfind( resource );
+ ExtraFolder* ef = mExtraFolders.find( resource );
if ( ef )
return ef->folder;
@@ -1713,7 +1713,7 @@ void KMailICalIfaceImpl::readConfig()
// configure things again.
kdDebug(5006) << "Groupware folder " << parentName << " not found. Groupware functionality disabled" << endl;
// Or maybe the inbox simply wasn't created on the first startup
- KMAccount* account = kmkernel->acctMgr()->tqfind( GlobalSettings::self()->theIMAPResourceAccount() );
+ KMAccount* account = kmkernel->acctMgr()->find( GlobalSettings::self()->theIMAPResourceAccount() );
Q_ASSERT( account );
if ( account ) {
// just in case we were connected already
@@ -1922,8 +1922,8 @@ void KMailICalIfaceImpl::readConfig()
KMFolderCachedImap *imapFolder = static_cast<KMFolderCachedImap*>( storage );
const TQString attributes = imapFolder->folderAttributes();
- if ( attributes.tqcontains( "X-FolderClass" ) ) {
- if ( !attributes.tqcontains( "X-SpecialFolder" ) || (*it)->location().tqcontains( "@" ) ) {
+ if ( attributes.contains( "X-FolderClass" ) ) {
+ if ( !attributes.contains( "X-SpecialFolder" ) || (*it)->location().contains( "@" ) ) {
const Scalix::FolderAttributeParser parser( attributes );
if ( !parser.folderClass().isEmpty() ) {
FolderContentsType type = Scalix::Utils::scalixIdToContentsType( parser.folderClass() );
@@ -1964,7 +1964,7 @@ void KMailICalIfaceImpl::slotCheckDone()
//kdDebug(5006) << k_funcinfo << " folderParent=" << folderParent << endl;
if ( folderParent ) // cool it exists now
{
- KMAccount* account = kmkernel->acctMgr()->tqfind( GlobalSettings::self()->theIMAPResourceAccount() );
+ KMAccount* account = kmkernel->acctMgr()->find( GlobalSettings::self()->theIMAPResourceAccount() );
if ( account )
disconnect( account, TQT_SIGNAL( finishedCheck( bool, ChecktqStatus ) ),
this, TQT_SLOT( slotCheckDone() ) );
@@ -1993,7 +1993,7 @@ KMFolder* KMailICalIfaceImpl::initFolder( KMail::FolderContentsType contentsType
i18n("There are multiple %1 default folders, please choose one:")
.tqarg( localizedDefaultFolderName( contentsType ) ), labels );
if ( !selected.isEmpty() )
- result.folder = result.folders[ labels.tqfindIndex( selected ) ];
+ result.folder = result.folders[ labels.findIndex( selected ) ];
}
KMFolder* folder = result.folder;
@@ -2051,7 +2051,7 @@ KMFolder* KMailICalIfaceImpl::initScalixFolder( KMail::FolderContentsType conten
KMFolderCachedImap *imapFolder = static_cast<KMFolderCachedImap*>( storage );
const TQString attributes = imapFolder->folderAttributes();
- if ( attributes.tqcontains( "X-SpecialFolder" ) ) {
+ if ( attributes.contains( "X-SpecialFolder" ) ) {
const Scalix::FolderAttributeParser parser( attributes );
if ( contentsType == Scalix::Utils::scalixIdToContentsType( parser.folderClass() ) ) {
folder = *it;
@@ -325,7 +325,7 @@ bool KMailICalIfaceImpl::kolabXMLFoundAndDecoded( const KMMessage& msg, const TQ
// return value: wrong if attachment could not be deleted
//
-// This code could be optimized: for now we just tqreplace
+// This code could be optimized: for now we just replace
// the attachment by an empty dummy attachment since Mimelib
// does not provide an option for deleting attachments yet.